==> bibledit-0.4.tar.gz: bibledit-0.4/src/configuration.h <==
/*
** Copyright (C) 2003 The Free Software Foundation.
**  
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**  
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**  
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
**  
*/

#ifndef INCLUDED_CONFIGURATION_H
#define INCLUDED_CONFIGURATION_H


#include "libraries.h"


string synchronization_paths_filename();


class Configuration {
  // Manages stored program settings.
 public:
  Configuration (Gtk::Window& window);
  ~Configuration ();
  string projectdirectory_reuse;	/* This can be reused */
  string projectshortcut_reuse;	/* This can be reused */
  string converttowebdirectory;
  int window_width;
  int window_height;
  int window_x_position;
  int window_y_position;
  int hpane_position;
  int vpane_position;		/* This can be reused */
  string book_opened;
  string chapter_opened;
  string verse_opened;
  string synchronize_paratext_projectdirectory; // Reuse
  bool synchronize_paratext; // Reuse
  string find_searchword;
  string find_replaceword;
  string references_file;
  bool companion_local_enabled;
  bool companion_remote_enabled;
  string companion_remote_name;
  string editor_font_name;
  string last_goto_reference;	/* This one can be reused */
  string project;
 private:
  string bibleditrc();
  int screen_width;
  int screen_height;
  bool screen_resolution_changed;
};


#endif

==> bibledit-0.5.tar.gz: bibledit-0.5/src/configuration.h <==
/*
** Copyright (C) 2003 The Free Software Foundation.
**  
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**  
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**  
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
**  
*/

#ifndef INCLUDED_CONFIGURATION_H
#define INCLUDED_CONFIGURATION_H


#include "libraries.h"
#include <gtk/gtk.h>


string synchronization_paths_filename ();


class Configuration
{
  // Manages stored program settings.
public:
  Configuration (GtkWindow *window);
  ~Configuration ();
  string projectdirectory_reuse;        /* This can be reused */
  string projectshortcut_reuse; /* This can be reused */
  string converttowebdirectory;
  int window_width;
  int window_height;
  int window_x_position;
  int window_y_position;
  int hpane_position;
  int vpane_position;
  string book_opened;
  string chapter_opened;
  string verse_opened;
  string synchronize_paratext_projectdirectory; // Reuse
  bool synchronize_paratext;    // Reuse
  string find_searchword;
  string find_replaceword;
  string references_file;
  bool companion_local_enabled;
  bool companion_remote_enabled;
  string companion_remote_name;
  string editor_font_name;
  string last_goto_reference;   /* This one can be reused */
  string project;
private:
  string bibleditrc ();
  int screen_width;
  int screen_height;
  bool screen_resolution_changed;
};


#endif
